==> nextcloud-app-contacts-4.1.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/th.js <==
OC.L10N.register(
    "contacts",
    {
    "Details" : "รายละเอียด",
    "All contacts" : "รายชื่อทั้งหมด",
    "Contacts" : "ข้อมูลผู้ติดต่อ",
    "Download" : "ดาวน์โหลด",
    "Groups" : "กลุ่ม",
    "Group name" : "ชื่อกลุ่ม",
    "Rename" : "เปลี่ยนชื่อ",
    "Enabled" : "เปิดการใช้งาน",
    "Delete" : "ลบ",
    "Copy link" : "คัดลอกลิงค์",
    "Share with users or groups" : "แชร์กับผู้ใช้หรือกลุ่ม",
    "can edit" : "สามารถแก้ไข",
    "First name" : "ชื่อจริง",
    "Last name" : "นามสกุลจริง",
    "Invalid image" : "รูปภาพไม่ถูกต้อง",
    "Name" : "ชื่อ",
    "Title" : "ชื่อเรื่อง",
    "Cancel" : "ยกเลิก",
    "New contact" : "รายชื่อผุ้ติดต่อใหม่",
    "Close" : "ปิด",
    "Import" : "นำเข้า",
    "Not grouped" : "ไม่ถูกจัดกลุ่ม",
    "Email" : "อีเมล",
    "Nickname" : "ชื่อเล่น",
    "Detailed name" : "รายละเอียดชื่อ",
    "Additional names" : "ชื่ออื่นๆ",
    "Prefix" : "คำนำหน้า",
    "Suffix" : "คำต่อท้าย",
    "Notes" : "บันทึกย่อ",
    "Website" : "เว็บไซต์",
    "Location" : "ตำแหน่งที่อยู่",
    "Federated Cloud ID" : "ไอดีคลาวด์ในเครือ",
    "Home" : "บ้าน",
    "Work" : "ที่ทำงาน",
    "Other" : "อื่นๆ",
    "Address" : "ที่อยู่",
    "Post office box" : "กล่องจดหมาย",
    "City" : "เมือง",
    "State or province" : "รัฐหรือจังหวัด",
    "Postal code" : "รหัสไปรษณีย์",
    "Country" : "ประเทศ",
    "Birthday" : "วันเกิด",
    "Anniversary" : "วันครบรอบ",
    "Date of death" : "วันที่สิ้นสุด",
    "Instant messaging" : "ส่งข้อความโต้ตอบแบบทันที",
    "Phone" : "โทรศัพท์",
    "Mobile" : "มือถือ",
    "Fax" : "โทรสาร",
    "Fax home" : "แฟกซ์ที่บ้าน",
    "Fax work" : "แฟกซ์ที่ทำงาน",
    "Pager" : "เพจเจอร์",
    "Voice" : "เสียงพูด",
    "Social network" : "เครือข่ายทางสังคม",
    "Relative" : "เครื่องญาติ",
    "None" : "ไม่มี",
    "Unknown" : "ไม่ทราบ"
},
"nplurals=1; plural=0;");

==> nextcloud-app-contacts-5.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/th.js <==
OC.L10N.register(
    "contacts",
    {
    "Details" : "รายละเอียด",
    "All contacts" : "รายชื่อทั้งหมด",
    "Contacts" : "ข้อมูลผู้ติดต่อ",
    "Download" : "ดาวน์โหลด",
    "Send email" : "ส่งอีเมล",
    "Groups" : "กลุ่ม",
    "Group name" : "ชื่อกลุ่ม",
    "Rename" : "เปลี่ยนชื่อ",
    "Enabled" : "เปิดการใช้งาน",
    "Delete" : "ลบ",
    "Copy link" : "คัดลอกลิงค์",
    "Share with users or groups" : "แชร์กับผู้ใช้หรือกลุ่ม",
    "can edit" : "สามารถแก้ไข",
    "First name" : "ชื่อจริง",
    "Last name" : "นามสกุลจริง",
    "Display name" : "ชื่อที่แสดง",
    "Password protection" : "ป้องกันด้วยรหัสผ่าน",
    "Save" : "บันทึก",
    "Description" : "รายละเอียด",
    "Invalid image" : "รูปภาพไม่ถูกต้อง",
    "Name" : "ชื่อ",
    "Title" : "ชื่อเรื่อง",
    "Cancel" : "ยกเลิก",
    "New contact" : "รายชื่อผุ้ติดต่อใหม่",
    "Search contacts …" : "ค้นหารายชื่อผู้ติดต่อ …",
    "No results" : "ไม่มีผลลัพธ์",
    "Pending" : "อยู่ระหว่างดำเนินการ",
    "Close" : "ปิด",
    "Import" : "นำเข้า",
    "Not grouped" : "ไม่ถูกจัดกลุ่ม",
    "User" : "ผู้ใช้",
    "Group" : "กลุ่ม",
    "Email" : "อีเมล",
    "Admin" : "ผู้ดูแลระบบ",
    "Owner" : "เจ้าของ",
    "Users" : "ผู้ใช้",
    "Nickname" : "ชื่อเล่น",
    "Detailed name" : "รายละเอียดชื่อ",
    "Additional names" : "ชื่ออื่นๆ",
    "Prefix" : "คำนำหน้า",
    "Suffix" : "คำต่อท้าย",
    "Notes" : "บันทึกย่อ",
    "Website" : "เว็บไซต์",
    "Location" : "ตำแหน่งที่อยู่",
    "Federated Cloud ID" : "ไอดีคลาวด์ในเครือ",
    "Home" : "บ้าน",
    "Work" : "ที่ทำงาน",
    "Other" : "อื่นๆ",
    "Address" : "ที่อยู่",
    "Post office box" : "กล่องจดหมาย",
    "City" : "เมือง",
    "State or province" : "รัฐหรือจังหวัด",
    "Postal code" : "รหัสไปรษณีย์",
    "Country" : "ประเทศ",
    "Birthday" : "วันเกิด",
    "Anniversary" : "วันครบรอบ",
    "Date of death" : "วันที่สิ้นสุด",
    "Instant messaging" : "ส่งข้อความโต้ตอบแบบทันที",
    "Phone" : "โทรศัพท์",
    "Mobile" : "มือถือ",
    "Fax" : "โทรสาร",
    "Fax home" : "แฟกซ์ที่บ้าน",
    "Fax work" : "แฟกซ์ที่ทำงาน",
    "Pager" : "เพจเจอร์",
    "Voice" : "เสียงพูด",
    "Social network" : "เครือข่ายทางสังคม",
    "Relative" : "เครื่องญาติ",
    "None" : "ไม่มี",
    "Unknown" : "ไม่ทราบ"
},
"nplurals=1; plural=0;");
